/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.ifeed.service.ifeed;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.transaction.annotation.Transactional;

import se.vgregion.dao.domain.patterns.repository.db.jpa.JpaRepository;
import se.vgregion.ifeed.types.IFeed;
import se.vgregion.ifeed.types.IFeedFilter;

public class IFeedServiceImpl implements IFeedService {

    private JpaRepository<IFeed, Long, Long> iFeedRepo;

    public IFeedServiceImpl(JpaRepository<IFeed, Long, Long> iFeedRepo) {
        this.iFeedRepo = iFeedRepo;
    }

    @Override
    public Collection<IFeed> getIFeeds() {
        return new ArrayList<IFeed>(iFeedRepo.findAll());
    }

    @Override
    public Collection<IFeed> getUserIFeeds(String userId) {
        return new ArrayList<IFeed>(iFeedRepo.findByQuery("SELECT ifeed FROM IFeed ifeed WHERE ifeed.userId=?1", new Object[] { userId }));
    }

    @Override
    public IFeed getIFeed(Long id) {
        return iFeedRepo.find(id);
    }

    @Override
    @Transactional
    public void addIFeed(IFeed iFeed) {
        iFeedRepo.store(iFeed);
    }

    @Override
    @Transactional
    public void removeIFeed(Long id) {
        iFeedRepo.remove(id);
    }

    @Override
    @Transactional
    public void updateIFeed(IFeed iFeed) {
        IFeed oldIFeed = iFeedRepo.find(iFeed.getId());
        if(oldIFeed == null || filterChanged(oldIFeed, iFeed)) {
            iFeed.clearTimestamp();
        }
        iFeedRepo.merge(iFeed);
    }

    private boolean filterChanged(IFeed oldIFeed, IFeed iFeed) {
        Collection<IFeedFilter> oldFilters = oldIFeed.getFilters();
        Collection<IFeedFilter> newFilters = iFeed.getFilters();

        return !CollectionUtils.isEqualCollection(oldFilters, newFilters);
    }

}
