/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.ifeed.service.solr;

import se.vgregion.ifeed.types.FilterType.Filter;
import se.vgregion.ifeed.types.IFeedFilter;

public class SolrQueryBuilder {

    public static String createQuery(IFeedFilter iFeedFilter) {
        String query = "";
        Filter filter = iFeedFilter.getFilter();
        String filterQuery = iFeedFilter.getFilterQuery();
        switch (filter.getMetadataType()) {
            case TEXT_FREE:
                query  = filter.getFilterField() + ":\"" + SolrQueryEscaper.escape(filterQuery) + "\"";
                break;
            case TEXT_FIX:
                query  = filter.getFilterField() + ":" + SolrQueryEscaper.escape(filterQuery) + "";
                break;
            case DATE:
                if(filter.name().contains("FROM_DATE")) {
                    query = filter.getFilterField() + ":[" + filterQuery + " TO *]";
                } else if(filter.name().contains("TO_DATE")) {
                    query = filter.getFilterField() + ":[* TO " + filterQuery + "]";
                } else {
                    throw new RuntimeException("Unable to build query. Unknown filter date type found: " + filter.name());
                }
                break;
            default:
                break;
        }
        return query;
    }
}
